@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2011 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: airtools.cpp,v 1.6 2011/08/15 20:45:51 cvs Exp $
+//      $Id: airtools.cpp,v 1.7 2011/08/16 22:26:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,9 +22,10 @@
 
 #include "airtools.h"
 
-AirTools::AirTools(Profile *p,int n,QObject *parent,const char *name)
-  : Delay(p,n,parent,name)
+AirTools::AirTools(Profile *p,int n,bool debug,QObject *parent,const char *name)
+  : Delay(p,n,debug,parent,name)
 {
+  airtools_stats_requested=false;
   airtools_state=Cunctator::StateEntered;
   airtools_delay_length=0;
   airtools_msg_istate=0;
@@ -95,6 +96,16 @@ bool AirTools::connect()
   QObject::connect(timer,SIGNAL(timeout()),this,SLOT(queryDelayData()));
   timer->start(AIRTOOLS_DELAY_INCREMENT);
 
+  if(debugMode()) {  // Get Software Statistics
+    char buffer[6];
+    snprintf(buffer,6,"%c%c%c%c%c",0xFB,0xFF&airtools_unit_address,
+	    0x00,0x02,0x10);
+    ApplyChecksum(buffer,5);
+    airtools_tty->writeBlock(buffer,6);
+    airtools_stats_requested=true;
+    printf("AirTools 6100 Driver\n");
+  }
+
   return true;
 }
 
@@ -150,6 +161,7 @@ void AirTools::readyReadData(int fd)
 
   while((n=airtools_tty->readBlock(data,1500))>0) {
     for(i=0;i<n;i++) {
+      //      printf("data[%d]: 0x%02X\n",i,0xFF&data[i]);
       switch(airtools_msg_istate) {
       case 0:  /* Unit Address */
 	if(data[i]==airtools_unit_address) {
@@ -176,7 +188,13 @@ void AirTools::readyReadData(int fd)
 
       case 4:  /* Message Length LSB */
 	if(data[i]==0x0C) {
-	  airtools_msg_istate=5;
+	  if(airtools_stats_requested) {
+	    airtools_stats_requested=false;
+	    airtools_msg_istate=100;
+	  }
+	  else {
+	    airtools_msg_istate=5;
+	  }
 	}
 	else {
 	  airtools_msg_istate=0;
@@ -236,6 +254,60 @@ void AirTools::readyReadData(int fd)
 	airtools_msg_istate=0;
 	break;
  
+      case 100:  // Host Revision Number MSB
+	airtools_host_revision_major=0xFF&data[i];
+	airtools_msg_istate=101;
+	break;
+
+      case 101:  // Host Revision Number LSB
+	airtools_host_revision_minor=0xFF&data[i];
+	printf("Host Version: R%d.%02d\n",
+	       airtools_host_revision_major,
+	       airtools_host_revision_minor);
+	airtools_msg_istate=102;
+	break;
+
+      case 102:  // Host Revision Day
+	airtools_msg_istate=103;
+	break;
+
+      case 103:  // Host Revision Month
+	airtools_msg_istate=104;
+	break;
+
+      case 104:  // Host Revision Year
+	airtools_msg_istate=105;
+	break;
+
+      case 105:  // DSP Revision Number MSB
+	airtools_dsp_revision_major=0xFF&data[i];
+	airtools_msg_istate=106;
+	break;
+
+      case 106:  // DSP Revision Number LSB
+	airtools_dsp_revision_minor=0xFF&data[i];
+	printf("DSP Version: R%d.%02d\n",
+	       airtools_dsp_revision_major,
+	       airtools_dsp_revision_minor);
+	airtools_msg_istate=107;
+	break;
+
+      case 107:  // DSP Revision Number Day
+	airtools_msg_istate=108;
+	break;
+
+      case 108:  // DSP Revision Number Month
+	airtools_msg_istate=109;
+	break;
+
+      case 109:  // DSP Revision Number Year
+	airtools_msg_istate=110;
+	break;
+
+      case 110:  // Status
+	airtools_msg_istate=16;
+	break;
+
       default:
 	airtools_msg_istate=0;
 	break;
@@ -251,7 +323,7 @@ void AirTools::SendCommand(unsigned mask)
 
   char buffer[10];
 
-  sprintf(buffer,"%c%c%c%c%c%c",0xFB,0xFF&airtools_unit_address,
+  snprintf(buffer,10,"%c%c%c%c%c%c",0xFB,0xFF&airtools_unit_address,
 	  0x00,0x03,0x90,0xFF&mask);
   ApplyChecksum(buffer,6);
   airtools_tty->writeBlock(buffer,7);
