@@ -30,10 +30,19 @@
 #include "airtools.h"
 #include "bd600.h"
 
-CuncConfig::CuncConfig(QObject *parent,const char *name)
+CuncConfig::CuncConfig(bool debug,QObject *parent,const char *name)
   : QObject(parent,name)
 {
   clear();
+  conf_debug=debug;
+}
+
+
+CuncConfig::CuncConfig(QString filename,bool debug)
+{
+  clear();
+  conf_filename=filename;
+  conf_debug=debug;
 }
 
 
@@ -43,13 +52,6 @@ CuncConfig::~CuncConfig()
 }
 
 
-CuncConfig::CuncConfig(QString filename)
-{
-  clear();
-  conf_filename=filename;
-}
-
-
 QString CuncConfig::filename() const
 {
   return conf_filename;
@@ -146,15 +148,15 @@ bool CuncConfig::load()
   while(ok) {
     added=false;
     if(str.lower()=="dummy") {
-      conf_delays.push_back(new Dummy(p,count-1,this));
+      conf_delays.push_back(new Dummy(p,count-1,conf_debug,this));
       added=true;
     }
     if(str.lower()=="airtools") {
-      conf_delays.push_back(new AirTools(p,count-1,this));
+      conf_delays.push_back(new AirTools(p,count-1,conf_debug,this));
       added=true;
     }
     if(str.lower()=="bd600") {
-      conf_delays.push_back(new Bd600(p,count-1,this));
+      conf_delays.push_back(new Bd600(p,count-1,conf_debug,this));
       added=true;
     }
     if(added) {
@@ -218,6 +220,7 @@ void CuncConfig::clear()
     delete conf_udp_queues[i];
   }
   conf_udp_queues.clear();
+  conf_debug=false;
 }
 
 
